/*
 * STM32F4xx_Framework V1.0
 * @file	stm32f4xx_ClockConfig.h
 * @brief	Defines HSE and HSI values,
 * 			Standard PLL values for 168MHz system clock from internal HSI oscillator
 * 			and prescalers for HCLK (AHB), PCLK1 (APB1), PCLK2 (APB2)
 *
 * 			NOTE: 	This Framework does not configure the system clock!
 * 					After Reset the controller is running from internal Oscillator!
 * 					This defines are just standard values that can be used in your
 * 					application for configuring the clocks to maximum speed.
 *
 * 			SYSCLK			max. 168MHz
 * 			HCLK <=> AHB 	max. 168MHz
 * 			PCLK1 <=> APB1 	max. 42MHz
 * 			PCLK2 <=> APB2 	max. 84MHz
 */


/*----------Define to prevent recursive inclusion-----------------------------*/
#ifndef __STM32F4XX_ClOCKCONFIG
#define __STM32F4XX_CLOCKCONFIG


/*----------HSE and HSI values------------------------------------------------*/
/*
 * Set to -1 to disable the concerning clock check
 */
#ifndef HSE_VALUE
	#define HSE_VALUE 			-1
#endif

#ifndef HSE_STARTUP_TIMEOUT
	#define HSE_STARTUP_TIMEOUT	0x0500
#endif

#ifndef HSI_VALUE
	#define HSI_VALUE			16000000
#endif


/*----------Standard PLL values for 168MHz system clock from HSI--------------*/
/*
 * PLL_VCO = (HSI_VALUE / PLL_M) * PLL_N
 */
#ifndef PLL_M
	#if(HSE_VALUE != -1)
		#define PLL_M	(HSE_VALUE / 2000000)
	#else
		#define PLL_M	(HSI_VALUE / 2000000)
	#endif
#endif

#ifndef PLL_N
	#define PLL_N 	168
#endif

/*
 * System clock = PLL_VCO / PLL_P
 */
#ifndef PLL_P
	#define PLL_P 	2
#endif

/*
 * USB OTG FS, SDIO and RNG clock = PLL_VCO / PLL_Q
 */
#ifndef PLL_Q
	#define PLL_Q	7
#endif


/*----------Standard Bus prescalers for 168MHz system clock from PLL-------------------*/
/*
 * HCLK = System clock / HCLK_DIV
 */
#ifndef HCLK_DIV
	#define HCLK_DIV		1
#endif

/*
 * PCLK1 = HCLK / PCLK1_DIV
 */
#ifndef PCLK1_DIV
	#define PCLK1_DIV		4
#endif

/*
 * PCLK2 = HCLK / PCLK2_DIV
 */
#ifndef PCLK2_DIV
	#define PCLK2_DIV		2
#endif


/*----------Check Clocks------------------------------------------------------*/
#define SYSCLK_MAX	168000000
#define HCLK_MAX	168000000
#define	PCLK1_MAX	42000000
#define PCLK2_MAX	84000000

#if(HSE_VALUE != -1)
	#define SYSCLK_HSE	(((HSE_VALUE / PLL_M) * PLL_N) / PLL_P)
	#define HCLK_HSE	(SYSCLK_HSE / HCLK_DIV)
	#define PCLK1_HSE	(HCLK_HSE / PCLK1_DIV)
	#define PCLK2_HSE	(HCLK_HSE / PCLK2_DIV)

	#if(SYSCLK_HSE > SYSCLK_MAX)
		#warning "SYSCLK from HSE is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(HCLK_HSE > HCLK_MAX)
		#warning "HCLK from HSE is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(PCLK1_HSE > PCLK1_MAX)
		#warning "PCLK1 from HSE is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(PCLK2_HSE > PCLK2_MAX)
		#warning "PCLK2 from HSE is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#undef SYSCLK_HSE
	#undef HCLK_HSE
	#undef PCLK1_HSE
	#undef PCLK2_HSE
#endif

#if(HSI_VALUE != -1)
	#define SYSCLK_HSI	(((HSI_VALUE / PLL_M) * PLL_N) / PLL_P)
	#define HCLK_HSI	(SYSCLK_HSI / HCLK_DIV)
	#define PCLK1_HSI	(HCLK_HSI / PCLK1_DIV)
	#define PCLK2_HSI	(HCLK_HSI / PCLK2_DIV)

	#if(SYSCLK_HSI > SYSCLK_MAX)
		#warning "SYSCLK from HSI is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(HCLK_HSI > HCLK_MAX)
		#warning "HCLK from HSI is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(PCLK1_HSI > PCLK1_MAX)
		#warning "PCLK1 from HSI is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#if(PCLK2_HSI > PCLK2_MAX)
		#warning "PCLK2 from HSI is to big. Check stm32f4xx_ClockConfig.h"
	#endif

	#undef SYSCLK_HSI
	#undef HCLK_HSI
	#undef PCLK1_HSI
	#undef PCLK2_HSI
#endif

#undef SYSCLK_MAX
#undef HCLK_MAX
#undef PCLK1_MAX
#undef PCLK2_MAX

#endif
